Scoria
======

What is it?
-----------

The scoria library is a lightweight python code base designed for
importing, manipulating, and exporting molecular models.

The Latest Version
------------------

Visit [https://git.durrantlab.com/jdurrant/scoria/tree/1.0.0](https://git.durrantlab.com/jdurrant/scoria/tree/1.0.0)
to download the latest version. The same version is mirrored on GitHub.

Visit [http://durrantlab.com/scoria/](http://durrantlab.com/scoria/) to:

* read the documenation
* suggest an improvement
* point out a bug
* ask a question about usage

For MDAnalysis support, download Scoria MDA instead: [https://git.durrantlab.com/jdurrant/scoria/tree/1.0.0_mda](https://git.durrantlab.com/jdurrant/scoria/tree/1.0.0_mda).

Licensing
---------

Scoria is released under the Apache 2.0 license. See LICENCE.txt for details.

Scoria MDA is derived from Scoria and includes MDAnalysis support. It is
released under the GNU General Public License version 3.0.

Installation
------------

The scoria libarary can be installed via pip as 

```bash
# for python 2
pip install scoria

# for python 3
pip3 install scoria
```

Scoria runs best with NumPy and SciPy. Some versions can also use the
MDAnalysis library for additional import methods. The first two dependancies
should be automatically installed alongside the package.

Authors and Contacts
--------------------

This library was produced by Jacob Durrant (durrantj@pitt.edu) with
the assistance of Patrick Ropp and Aaron Friedman.
